@@ -236,7 +236,16 @@ class Repo(object):
         if not filenames is None:
             cmds += list(filenames)
 
-        return self.hg_command(*cmds)
+        result =  self.hg_command(*cmds)
+        diffs = []
+        filere = re.compile("^diff .* (\S+)$")
+        for line in result.split('\n'):
+           
+            match = filere.match(line)
+            if match:
+                diffs.append({'filename': match.groups()[0],  'diff': ''})
+            diffs[-1]['diff'] += line + '\n'
+        return diffs
 
     def hg_status(self, empty=False, clean=False):
         """Get repository status.
