@@ -309,20 +309,15 @@ class TestHgAPI(unittest.TestCase):
         self.assertFalse("commit test_branch" in default)
 
     def test_230_BasicDiff(self):
-        diff = self.repo.hg_diff('default', 'test_branch')
-        self.assertTrue('.hgtags' in diff)
-        self.assertTrue('+even more stuff' in diff)
-
-        self.assertTrue(diff.startswith('diff -r'))
+        diffs = self.repo.hg_diff('default', 'test_branch')
+        self.assertTrue('.hgtags' in [diff['filename'] for diff in diffs])
+        self.assertTrue('+even more stuff' in diffs[1]['diff'])
 
     def test_240_DiffFile(self):
-        diff = self.repo.hg_diff('default', 'test_branch', filenames=['file.txt'])
-        self.assertFalse('.hgtags' in diff)
-        self.assertTrue('file.txt' in diff)
-        self.assertTrue('+even more stuff' in diff)
-        self.assertTrue(diff.startswith('diff -r'))
-
-
+        diffs = self.repo.hg_diff('default', 'test_branch', filenames=['file.txt'])
+        self.assertEquals(len(diffs), 1)
+        self.assertEquals(diffs[0]['filename'], 'file.txt')
+        self.assertTrue('+even more stuff' in diffs[0]['diff'])
 
 def test_doc():
     #Prepare for doctest
